@@ -177,6 +177,7 @@ void   Gen_Rand (ITEM_TYPE Buf[], int Size);
 int main (int, char *argv[]) 
 {
   int        Size = atoi (argv [1]);
+  int i;
 #if defined (__GNUC__) && !defined (__STRICT_ANSI__)
   ITEM_TYPE  Buf [Size];
 #else
@@ -190,7 +191,7 @@ int main (int, char *argv[])
   Binary_Search   Bar (Buf, Size);
   
   start_timer ();
-  for (int i = 0; i < Size ; i++) 
+  for (i = 0; i < Size ; i++) 
     if (! Bar.Is_Member (Buf [i]))
       cout << "bad news, buf [" << i << "] = " << Buf [i] << "!\n";
 
