@@ -1,8 +1,7 @@
 #ifndef _BS_PRIMS
 #define _BS_PRIMS
 
-/* For now, use unsigned short for compatibility with old libg++ code.
-   Later, change to unsigned long as the default. */
+/* A bitstring is an array of _BS_word. */
 typedef unsigned long _BS_word;
 
 #define _BS_CHAR_BIT 8
@@ -34,9 +33,9 @@ typedef unsigned long _BS_word;
 #endif
 
 #if _BS_BIGENDIAN
-#define _BS_BITMASK(BITNO) (1 << (_BS_BITS_PER_WORD - 1 - (BITNO)))
+#define _BS_BITMASK(BITNO) ((_BS_word)1 << (_BS_BITS_PER_WORD - 1 - (BITNO)))
 #else
-#define _BS_BITMASK(BITNO) (1 << (BITNO))
+#define _BS_BITMASK(BITNO) ((_BS_word)1 << (BITNO))
 #endif
 
 /* Given a PTR which may not be aligned on a _BS_word boundary,
@@ -46,7 +45,7 @@ typedef unsigned long _BS_word;
   ( (NEW_PTR) = (_BS_word*)(((char*)(PTR)-(char*)0) & ~(sizeof(_BS_word)-1)), \
     (OFFSET) += (char*)(PTR) - (char*)(NEW_PTR) )
 
-/* Given a bit point (PTR, OFFSET) normalize it so that
+/* Given a bit pointer (PTR, OFFSET) normalize it so that
    OFFSET < _BS_BITS_PER_WORD. */
 #define _BS_NORMALIZE(PTR, OFFSET) \
 { _BS_size_t __tmp_ind = _BS_INDEX (OFFSET); \
@@ -57,7 +56,7 @@ typedef unsigned long _BS_word;
 #define _BS_POS(I) ((I) & (_BS_BITS_PER_WORD -1 ))
 
 #ifndef _BS_size_t
-#ifdef __GNUC__
+#if __GNUC__ > 1
 #define _BS_size_t __SIZE_TYPE__
 #else
 #define _BS_size_t unsigned long
@@ -115,7 +114,8 @@ extern int _BS_any __P((const _BS_word*, int, _BS_size_t));
 extern void _BS_clear __P((_BS_word*, int, _BS_size_t));
 extern void _BS_set __P((_BS_word*, int, _BS_size_t));
 extern void _BS_invert __P((_BS_word*, int, _BS_size_t));
-int _BS_lcompare_0 __P((_BS_word*, _BS_size_t, _BS_word*, _BS_size_t));
+int _BS_lcompare_0 __P((const _BS_word*, _BS_size_t,
+			const _BS_word*, _BS_size_t));
 extern void _BS_xor __P((_BS_word*,int, const _BS_word*,int, _BS_size_t));
 
 #ifdef __cplusplus
