@@ -13,8 +13,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU CC; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+along with this library; see the file COPYING.  If not, write to the Free
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 As a special exception, if you link this library with files
 compiled with a GNU compiler to produce an executable, this does not cause
@@ -25,9 +25,9 @@ the executable file might be covered by the GNU General Public License. */
 #include "libioP.h"
 #include <string.h>
 
-int _IO_fputs(str, fp)
-     const char *str;
-     _IO_FILE *fp;
+int
+DEFUN(_IO_fputs, (str, fp),
+      const char *str AND _IO_FILE *fp)
 {
   _IO_size_t len = strlen(str);
   CHECK_FILE(fp, EOF);
