@@ -31,6 +31,7 @@ Written by Per Bothner (bothner@cygnus.com). */
 #endif
 #include "streambuf.h"
 
+extern "C++" {
 // A parsebuf is a streambuf optimized for scanning text files.
 // It keeps track of line and column numbers.
 // It is guaranteed to remember the entire current line,
@@ -151,4 +152,5 @@ class parsestream : public istream {
     int line_number();
 };
 #endif
+} // extern "C++"
 #endif /*!defined(PARSESTREAM_H)*/
