@@ -1,5 +1,5 @@
-#include <stdio.h>
-#include <libioP.h>
+#include "stdio.h"
+#include "libioP.h"
 
 int
 fseek(fp, offset, whence)
@@ -7,6 +7,6 @@ fseek(fp, offset, whence)
      long int offset;
      int whence;
 {
-  COERCE_FILE(fp);
+  CHECK_FILE(fp, -1);
   return _IO_fseek(fp, offset, whence);
 }
