@@ -5,7 +5,9 @@
 
 #include <std/bastring.h>
 
+extern "C++" {
 typedef basic_string <char, string_char_traits <char> > string;
 // typedef basic_string <wchar_t, string_char_traits <wchar_t> > wstring;
+} // extern "C++"
 
 #endif
